==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/uk.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Активність",
    "Error loading activities" : "Помилка завантаження подій",
    "No activities" : "Активність відсутня",
    "Load more activities" : "Завантажити більше активності",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C щоб скопіювати.",
    "{name} (invisible)" : "{name} (невидимо)",
    "{name} (restricted)" : "{name} (обмежено)",
    "in {path}" : "в {path}",
    "This stream will show events like additions, changes & shares" : "У цьому потоці будуть показані події, на кшталт доповнення, зміни та поширення",
    "There are no events for this filter" : "За цим фільтром події відсутні",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "Activity" : "Ваші дії",
    "Personal activity feed for %s" : "Персональна стрічка оновлень для %s",
    "Your feed URL is invalid" : "Ваше посилання новинної стрічки неправильна",
    "Your settings have been updated." : "Налаштування оновлені.",
    "Mail" : "Пошта",
    "Stream" : "Потік",
    "All activities" : "Всі дії",
    "By others" : "Іншими",
    "By you" : "Вами",
    "\"remote user\"" : "\"віддалений користувач\"",
    "Activity notification" : "Повідомлення про події",
    ", " : ",",
    "%s and %s" : "%s і %s",
    "Hello %s," : "Привіт %s,",
    "You are receiving this email because the following things happened at %s" : "Ви отримали це повідомлення, оскільки на %s відбувається наступне",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["1","кілька","* та ще %n"],
    "List your own actions in the stream" : "Перелічіть ваші власні дії в потоці",
    "Notify about your own actions via email" : "Повідомляти про мої дії по email",
    "You need to set up your email address before you can receive notification emails." : "Для отримання повідомлень вкажіть свій e-mail в особистих налаштуваннях.",
    "Send emails:" : "Відправляти електронні повідомлення:",
    "Hourly" : "Щогодини",
    "Daily" : "Щоденно",
    "Weekly" : "Щотижня",
    "Activity feed" : "Стрічка оновлень",
    "Enable RSS feed" : "Активувати RSS стрічку",
    "No activity yet" : "Поки що активність відсутня",
    "No more events to load" : "Більше немає подій для завантаження",
    "Files" : "Файли"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/uk.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Активність",
    "An error occurred while loading activities" : "Під час заванатаження подій відбулася помилка",
    "No activity yet" : "Поки що активність відсутня",
    "Load more activities" : "Завантажити більше активності",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C щоб скопіювати.",
    "{name} (invisible)" : "{name} (невидимо)",
    "{name} (restricted)" : "{name} (обмежено)",
    "in {path}" : "в {path}",
    "This stream will show events like additions, changes & shares" : "У цьому потоці будуть показані події, на кшталт доповнення, зміни та поширення",
    "There are no events for this filter" : "За цим фільтром події відсутні",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "Personal activity feed for %s" : "Персональна стрічка оновлень для %s",
    "Your feed URL is invalid" : "Ваше посилання новинної стрічки неправильна",
    "Your settings have been updated." : "Налаштування оновлені.",
    "Settings have been updated." : "Налаштування було оновлено.",
    "Mail" : "Пошта",
    "Stream" : "Потік",
    "All activities" : "Всі дії",
    "By others" : "Іншими",
    "By you" : "Вами",
    "\"remote user\"" : "\"віддалений користувач\"",
    "Hello %s," : "Привіт %s,",
    "There was some activity at %s" : "Остання подія відбулася о %s",
    "Activity notification" : "Повідомлення про події",
    ", " : ",",
    "%s and %s" : "%s і %s",
    "Activity" : "Ваші дії",
    "Activity feed" : "Стрічка оновлень",
    "List your own actions in the stream" : "Перелічіть ваші власні дії в потоці",
    "Notify about your own actions via email" : "Повідомляти про мої дії по email",
    "You need to set up your email address before you can receive notification emails." : "Для отримання повідомлень вкажіть свій e-mail в особистих налаштуваннях.",
    "Send emails:" : "Відправляти електронні повідомлення:",
    "Hourly" : "Щогодини",
    "Daily" : "Щоденно",
    "Weekly" : "Щотижня",
    "Settings" : "Налаштування",
    "Enable RSS feed" : "Активувати RSS стрічку",
    "No more events to load" : "Більше немає подій для завантаження",
    "Files" : "Файли"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
